@@ -10,9 +10,9 @@
 #
 #
 "Kf" <-
-function(S=35,T=25,P=0,kf='pf'){
+function(S=35,T=25,P=0,kf='pf',pHscale="T"){
 
-nK <- max(length(S), length(T), length(P), length(kf))
+nK <- max(length(S), length(T), length(P), length(kf), length(pHscale))
 
 ##-------- Creation de vecteur pour toutes les entrees (si vectorielles)
 
@@ -20,6 +20,7 @@ if(length(S)!=nK){S <- rep(S[1], nK)}
 if(length(T)!=nK){T <- rep(T[1], nK)}
 if(length(P)!=nK){P <- rep(P[1], nK)}
 if(length(kf)!=nK){kf <- rep(kf[1], nK)}
+if(length(pHscale)!=nK){pHscale <- rep(pHscale[1], nK)}
  
 #-------Constantes----------------
 
@@ -126,10 +127,19 @@ Kf[i] = Kf[i]*tmp2;
 }
 }
  
+###----------------pH scale corrections
+factor <- rep(NA,nK)
+pHsc <- rep(NA,nK)
+for(i in (1:nK)){   
+ if(pHscale[i]=="T"){factor[i] <- 1 ; pHsc[i] <- "total scale"}
+ if(pHscale[i]=="F"){factor[i] <- kconv(S=S[i], T=T[i], P=P[i])$ktotal2free ; pHsc[i] <- "free scale"}
+ if(pHscale[i]=="SWS"){factor[i] <- kconv(S=S[i], T=T[i], P=P[i])$ktotal2SWS ; pHsc[i] <- "seawater scale"}
+Kf[i] <- Kf[i]*factor[i]
+}
 
 
 attr(Kf,"unit")     = "mol/kg-soln"
-attr(Kf,"pH scale") = "total hydrogen ion concentration"
+attr(Kf,"pH scale") = pHsc
 return(Kf)
 }
 
