@@ -13,9 +13,19 @@
 #
 
 buffer <- 
-function (flag, var1, var2, S=35, T=25, P=0, Pt=0, Sit=0){
-Carb <- carb(flag, var1, var2, S=35, T=25, P=0, Pt=0, Sit=0)
+function(flag, var1, var2, S=35, T=25, P=0, Pt=0, Sit=0, k1k2='l', kf='pf', pHscale="T"){
+Carb <- carb(flag=flag, var1=var1, var2=var2, S=S, T=T, P=P, Pt=Pt, Sit=Sit, k1k2=k1k2, kf=kf, pHscale=pHscale)
 RES <- data.frame()
+
+n <- nrow(Carb)
+
+k1k2.V <- k1k2
+if(length(k1k2.V)!=n){k1k2.V <- rep(k1k2.V[1], n)}
+kf.V <- kf
+if(length(kf.V)!=n){kf.V <- rep(kf.V[1], n)}
+pHscale.V <- pHscale
+if(length(pHscale.V)!=n){pHscale.V <- rep(pHscale.V[1], n)}
+
 	for (i in (1:nrow(Carb))){
 
 	S <- Carb[i,2]
@@ -33,6 +43,10 @@ RES <- data.frame()
 	Oa <- Carb[i,13]
 	Oc <- Carb[i,14]
 
+	k1k2 <- k1k2.V[i]
+	kf <- kf.V[i]
+	pHscale <- pHscale.V[i]
+
 #-------Constantes----------------
 
 tk = 273.15;           # [K] (for conversion [deg C] <-> [K])
@@ -54,19 +68,21 @@ fluo = (7*(S/35))*1e-5        # (mol/kg), DOE94 fluoride total
 #--------------------- calcul des K ----------------------------------
 #---------------------------------------------------------------------
 
-K1 <- K1(S=S, T=T, P=P)
-K2 <- K2(S=S, T=T, P=P)
+K1 <- K1(S=S, T=T, P=P, pHscale=pHscale, k1k2=k1k2)   
+K2 <- K2(S=S, T=T, P=P, pHscale=pHscale, k1k2=k1k2)
 Ks <- Ks(S=S, T=T, P=P)
-Kf <- Kf(S=S, T=T, P=P)
-Kw <- Kw(S=S, T=T, P=P)
+Kf <- Kf(S=S, T=T, P=P, pHscale=pHscale, kf=kf)
+Kw <- Kw(S=S, T=T, P=P, pHscale=pHscale)
 Kh <- Kh(S=S, T=T, P=P)
-Kb <- Kb(S=S, T=T, P=P)
-K1p <- K1p(S=S, T=T, P=P)
-K2p <- K2p(S=S, T=T, P=P)
-K3p <- K3p(S=S, T=T, P=P)
-Ksi <- Ksi(S=S, T=T, P=P)
+Kb <- Kb(S=S, T=T, P=P, pHscale=pHscale)
+K1p <- K1p(S=S, T=T, P=P, pHscale=pHscale)
+K2p <- K2p(S=S, T=T, P=P, pHscale=pHscale)
+K3p <- K3p(S=S, T=T, P=P, pHscale=pHscale)
+Ksi <- Ksi(S=S, T=T, P=P, pHscale=pHscale)
 Kspa <- Kspa(S=S, T=T, P=P)
 Kspc <- Kspc(S=S, T=T, P=P)
+	
+rho <- rho(S=S,T=T,P=P)
 
 #---------------------------------------------------------------------
 #--------------------    buffer effects    ---------------------------
